NpgHttpResponse class

The response of an HTTP call made by the plugin, reduced to what the NPG orders API needs.

Constructors

NpgHttpResponse(int statusCode, String body)
Creates a response with the given statusCode and body.
const

Properties

body String
Decoded response body.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
HTTP status code of the response.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited